##
##  tmux.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         tmux
Summary:      Terminal Multiplexer
URL:          https://github.com/tmux/tmux
Vendor:       Nicholas Marriott
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Terminal
License:      BSD
Version:      3.5a
Release:      20241010

#   list of sources
Source0:      https://github.com/tmux/tmux/releases/download/%{version}/tmux-%{version}.tar.gz
Source1:      tmux.conf
Source2:      tmux-session.sh
Source3:      tmux-session.1
Patch0:       tmux.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  libevent, ncurses
PreReq:       libevent, ncurses

%description
    TMUX is a "terminal multiplexer", it enables a number of terminals
    (or windows) to be accessed and controlled from a single terminal.
    TMUX is intended to be a simple, modern, BSD-licensed alternative to
    programs such as GNU screen.

%track
    prog tmux = {
        version   = %{version}
        url       = https://github.com/tmux/tmux/releases
        regex     = tree/(\d+(?:\.\d+)+[a-z]?)
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O} -Wno-pointer-sign" \
    CPPFLAGS="%{l_cppflags ncurses .}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/tmux
    %{l_make} %{l_mflags -O} \
        PREFIX="%{l_prefix}"

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/tmux \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1
    %{l_shtool} install -c -s -m 755 \
        tmux $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE tmux.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/tmux/
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE tmux-session.sh} $RPM_BUILD_ROOT%{l_prefix}/bin/tmux-session
    %{l_shtool} install -c -m 644 \
        %{SOURCE tmux-session.1} $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    %{l_shtool} install -c -m 644 \
        -e 's;@SYSCONFDIR@;%{l_prefix}/etc/tmux;g' \
        tmux.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/tmux/*'

%files -f files

%clean

